"""
@Project:bailan_bad
@File:bad_recognition.py
@Author:郑智
@Date:14:11
""" 
array = [10, 17, 50, 7, 30, 24, 27, 45, 15, 5, 36, 21]
def bubble_sort():
    for i in range(1, len(array)):
        for j in range(0, len(array) - i):
            if array[j] > array[j + 1]:
                array[j], array[j + 1] = array[j + 1], array[j]
    return array
print(bubble_sort())


"""
@Project:bailan_bad
@File:setup.py
@Author:郑智
@Date:14:12
""" 
from setuptools import setup, find_packages
setup(name="bailan",
      version="0.0.2",
      author="zhengzhi",
      author_email="3461736320@qq.com",
      #项目主页
      url="https://gitee.com/zheng--zhi/bailan.git",
      # 你要安装的包，通过 setuptools.find_packages 找到当前目录下有哪些包
      packages=find_packages() )